==> kubernetes-model-apiextensions-6.6.0-sources.jar: io/fabric8/kubernetes/api/model/apiextensions/v1/CustomResourceValidationFluent.java <==
package io.fabric8.kubernetes.api.model.apiextensions.v1;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public interface CustomResourceValidationFluent<A extends CustomResourceValidationFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildOpenAPIV3Schema instead.
   * @return The buildable object.
   */
  @Deprecated
  public JSONSchemaProps getOpenAPIV3Schema();
  public JSONSchemaProps buildOpenAPIV3Schema();
  public A withOpenAPIV3Schema(JSONSchemaProps openAPIV3Schema);
  public Boolean hasOpenAPIV3Schema();
  public CustomResourceValidationFluent.OpenAPIV3SchemaNested<A> withNewOpenAPIV3Schema();
  public CustomResourceValidationFluent.OpenAPIV3SchemaNested<A> withNewOpenAPIV3SchemaLike(JSONSchemaProps item);
  public CustomResourceValidationFluent.OpenAPIV3SchemaNested<A> editOpenAPIV3Schema();
  public CustomResourceValidationFluent.OpenAPIV3SchemaNested<A> editOrNewOpenAPIV3Schema();
  public CustomResourceValidationFluent.OpenAPIV3SchemaNested<A> editOrNewOpenAPIV3SchemaLike(JSONSchemaProps item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface OpenAPIV3SchemaNested<N> extends Nested<N>,JSONSchemaPropsFluent<CustomResourceValidationFluent.OpenAPIV3SchemaNested<N>>{
    public N and();
    public N endOpenAPIV3Schema();
    
  }
  
}

==> kubernetes-model-apiextensions-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/apiextensions/v1/CustomResourceValidationFluent.java <==
package io.fabric8.kubernetes.api.model.apiextensions.v1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface CustomResourceValidationFluent<A extends CustomResourceValidationFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildOpenAPIV3Schema instead.
   * @return The buildable object.
   */
  @Deprecated
  public JSONSchemaProps getOpenAPIV3Schema();
  public JSONSchemaProps buildOpenAPIV3Schema();
  public A withOpenAPIV3Schema(JSONSchemaProps openAPIV3Schema);
  public Boolean hasOpenAPIV3Schema();
  public CustomResourceValidationFluent.OpenAPIV3SchemaNested<A> withNewOpenAPIV3Schema();
  public CustomResourceValidationFluent.OpenAPIV3SchemaNested<A> withNewOpenAPIV3SchemaLike(JSONSchemaProps item);
  public CustomResourceValidationFluent.OpenAPIV3SchemaNested<A> editOpenAPIV3Schema();
  public CustomResourceValidationFluent.OpenAPIV3SchemaNested<A> editOrNewOpenAPIV3Schema();
  public CustomResourceValidationFluent.OpenAPIV3SchemaNested<A> editOrNewOpenAPIV3SchemaLike(JSONSchemaProps item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface OpenAPIV3SchemaNested<N> extends Nested<N>,JSONSchemaPropsFluent<CustomResourceValidationFluent.OpenAPIV3SchemaNested<N>>{
    public N and();
    public N endOpenAPIV3Schema();
    
  }
  
}
